Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Server ¶
type Server struct {
// contains filtered or unexported fields
}
Server implements an HTTP server which exposes a JSON API to view and manage gocraft/work items.
func NewServer ¶
NewServer creates and returns a new server. The 'namespace' param is the redis namespace to use. The hostPort param is the address to bind on to expose the API.
func NewWrappedServer ¶
func NewWrappedServer(namespace string, pool *redis.Pool, hostPort string, wrapHandler func(http.Handler) http.Handler) *Server
NewWrappedServer creates and returns a new server (like NewServer), but takes a wapper function which will be passed the server's http.Handler, and uses the result as the new server's handler.
Click to show internal directories.
Click to hide internal directories.